@@ -15,7 +15,7 @@ class JobConfiguration(DataProcessingObject):
         """
         jobconfiguration_id = jobconfiguration_id if jobconfiguration_id else self.value['id'] 
         
-        response = self._client.post(self._api, f'Jobs/Execution/{jobconfiguration_id}', '')
+        response = self._client._post(self._api, f'Jobs/Execution/{jobconfiguration_id}', '')
         
         return response['jobId']
 
@@ -30,7 +30,7 @@ class JobConfiguration(DataProcessingObject):
         if not 'configurationId' in parameters:
             parameters['configurationId'] =  self.value['id']
 
-        jobs = self._client.get(self._api, 'Jobs', parameters)
+        jobs = self._client._get(self._api, 'Jobs', parameters)
         
         return jobs
 
