@@ -24,8 +24,8 @@ class v2Object(Object):
         """
         
         if id:
-            self.value = self._client.get(self._api, f'{self._endpoint}/{id}', parameters)
+            self.value = self._client._get(self._api, f'{self._endpoint}/{id}', parameters)
         else:
-            self.value = self._client.get(self._api, self._endpoint, parameters)
+            self.value = self._client._get(self._api, self._endpoint, parameters)
     
         return self
\ No newline at end of file
